@@ -1,4 +1,4 @@
-from ..core import Core
+from ..core import Core, Settings
 
 
 class CheckService(Core):
@@ -7,9 +7,12 @@ class CheckService(Core):
     endpoint = None
 
     def __init__(self, service):
+        super().__init__()
         if service == 'elasticsearch':
+            self.host = Settings.elasticsearch
             self.endpoint = '/_cluster/health?wait_for_status=yellow'
         elif service == 'kibana':
+            self.host = Settings.kibana
             self.endpoint = '/api/status'
 
     def parse_response(self, response):
